@@ -19,6 +19,10 @@
  *      Mathias Hasselmann
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "libepc/consumer.h"
 
 #include "libepc/enums.h"
